<?php

namespace App\DataTables;

use Yajra\DataTables\DataTableAbstract;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Services\DataTable;
use Illuminate\Support\Facades\Http;

class LeadsDataTable extends DataTable
{
    /**
     * Build the DataTable class.
     *
     * @param DataTableAbstract $query
     */
    public function dataTable($query): DataTableAbstract
    {
        return datatables()->of($query)
            ->editColumn('lead_courses', function ($row) {
                // Transform lead_courses into a comma-separated list of course names
                return implode(', ', array_column($row['lead_courses'], 'course_name'));
            });
    }

    /**
     * Get the query source of dataTable.
     *
     * @return \Illuminate\Support\Collection
     */
    public function query()
    {
        // Fetch data from the external API
        $token = session('bearer_token');
        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/leads');
        
        if ($response->successful()) {
            $data = $response->json();
            return collect($data['data'] ?? []);
        }

        return collect([]);
    }

    /**
     * Optional method if you want to use the HTML builder.
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
                    ->setTableId('leads_table')
                    ->columns($this->getColumns())
                    ->minifiedAjax(route('leads_list'))
                    ->orderBy(1)
                    ->selectStyleSingle();
    }

    /**
     * Get the DataTable columns definition.
     */
    public function getColumns(): array
    {
        return [
            Column::computed('action')
                  ->exportable(false)
                  ->printable(false)
                  ->width(200)
                  ->addClass('text-center'),
            Column::make('id'),
            Column::make('name'),
            Column::make('phone'),
            Column::make('lead_manager'),
            Column::make('status_name'),
            Column::make('lead_courses'), // Display transformed course names
            Column::make('feedback'),
            Column::make('next_follow_up'),
            Column::make('assigned'),
        ];
    }

    /**
     * Get the filename for export.
     */
    protected function filename(): string
    {
        return 'Leads_' . date('YmdHis');
    }
}
