<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Http;
use App\DataTables\CoursesDataTable;

class CoursesController extends Controller
{
    public function home()
    {
        // Retrieve the bearer token from the session
        $token = session('bearer_token');
    
        // Check if the token is present
        if (!$token) {
            // Handle the case where the token is missing
            return redirect()->route('login')->with('error', 'Authentication token is missing. Please log in again.');
        }
    
        // Fetch data from the stats API with the bearer token
        $statsResponse = Http::withToken($token)->get('https://microsols.com.au/api/public/api/stats');
    
        // Check if the stats request was successful
        if (!$statsResponse->successful()) {
            $error = $statsResponse->body(); // or $statsResponse->json() if response is JSON
            return redirect()->route('home')->with('error', "Failed to fetch stats data from the API: $error");
        }
    
        // Decode the JSON response into an associative array for stats
        $statsData = $statsResponse->json();
        $totalStudents = $statsData['total_students'];
        $totalTeachers = $statsData['total_teachers'];
        $totalCourses = $statsData['total_courses'];
        $totalStaff = $statsData['total_staff'];
    
        // Fetch data from the courses API with the bearer token
        $coursesResponse = Http::withToken($token)->get('https://microsols.com.au/api/public/api/course');
    
        // Check if the courses request was successful
        if (!$coursesResponse->successful()) {
            $error = $coursesResponse->body(); // or $coursesResponse->json() if response is JSON
            return redirect()->route('home')->with('error', "Failed to fetch courses data from the API: $error");
        }
    
        // Decode the JSON response into an associative array for courses
        $coursesData = $coursesResponse->json();
        $courses = collect($coursesData['courses']); // Collect the courses into a Laravel collection
    
        // Pass all the data to the view
        return view('admin.index', compact('totalStudents', 'totalTeachers', 'totalCourses', 'totalStaff', 'courses'));
    }
    





    public function courses_list(CoursesDataTable $dataTable)
    {
        if (!hasPermission('courses')) {
            return response()->json(['error' => 'Route not Found'], 404);
        }
        return $dataTable->render('admin.courses.courses_list');
    }
    public function storeCourse(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'abbreviation' => 'required|string|max:6',
            'description' => 'required|string',
        ]);

        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/course', [
                'name' => $request->name,
                'abbreviation' => $request->abbreviation,
                'description' => $request->description
            ]);

            if ($response->successful()) {
                return response()->json(['success' => true, 'course' => $response->json()['course']]);
            } else {
                $error = $response->json();
                return response()->json(['success' => false, 'message' => $error['message'] ?? 'Failed to add course.'], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'Something went wrong: ' . $e->getMessage()], 500);
        }
    }


    public function deleteCourse($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/course/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Course deleted successfully']);
        } else {
            // Extract the message from the API response
            $apiMessage = $response->json('message', 'Unable to delete course');

            return response()->json(['success' => false, 'message' => $apiMessage], 400);
        }
    }


    public function updateCourse(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'abbreviation' => 'required|string|max:6',
            'description' => 'required|string',
        ]);

        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/course/{$id}", [
                'name' => $request->name,
                'abbreviation' => $request->abbreviation,
                'description' => $request->description
            ]);

            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Course updated successfully.']);
            } else {
                return response()->json(['success' => false, 'message' => 'Failed to update course.'], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
            'success' => false, 
            'message' => 'An error occurred: ' . $e->getMessage()
        ], 500);
        }
    }

    public function getCourse($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/course/{$id}");

            if ($response->successful()) {
                return response()->json(['course' => $response->json()]);
            } else {
                return response()->json(['status' => 404, 'message' => 'Course not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
}
