<?php

namespace App\Http\Controllers;

use App\Rules\Cnic;
use Illuminate\Http\Request;
use App\DataTables\EnrollDataTable;
use Illuminate\Support\Facades\Http;

class EnrollController extends Controller
{
    public function fetch_leads(): array
    {
        $token = session('bearer_token');

        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/leads');

        if ($response->successful()) {
            $leads = $response->json()['data'] ?? [];
            // Extract only the necessary columns
            $leads_list = array_map(function ($leads) {
                return [
                    'id' => $leads['id'],
                    'name' => $leads['name'],
                ];
            }, $leads);

            return $leads_list;
        }

        return [];
    }
    public function fetch_teachers(): array
    {
        $token = session('bearer_token');

        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/teachers');

        if ($response->successful()) {
            $teachers = $response->json()['data'] ?? [];
            // Extract only the necessary columns
            $teacher_list = array_map(function ($teacher) {
                return [
                    'id' => $teacher['id'],
                    'name' => $teacher['name'],
                ];
            }, $teachers);

            return $teacher_list;
        }

        return [];
    }
    public function enrollments_list(EnrollDataTable $dataTable)
    {
        $leads = $this->fetch_leads();
        $teachers = $this->fetch_teachers();
        return $dataTable->render('admin.enrollments.enrollment_list', compact('leads', 'teachers'));
    }
    public function add_enrollment_form(Request $request)
    {
        // Validate the request data
        $request->validate([
            'lead_id' => 'required|integer',
            'email' => 'required|email',
            'password' => 'required',
            'address' => 'required',
            'cnic' => 'required|numeric',
            'enrollments' => 'required|array',
            'enrollments.*.course_id' => 'required|integer',
            'enrollments.*.teacher_id' => 'required|integer',
            'enrollments.*.class_timing' => 'required|string',
        ]);
    
        try {
            $token = session('bearer_token');
            $data = [
                'lead_id' => $request->lead_id,
                'email' => $request->email,
                'cnic' => $request->cnic,
                'password' => $request->password,
                'address' => $request->address,
                'enrollments' => $request->enrollments,
            ];
    
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/enrollments/indirect', $data);
    
            if ($response->successful()) {
                return response()->json([
                    'success' => true,
                    'message' => 'Enrollment added successfully.',
                    'data' => $response->json()['data']
                ]);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add enrollment.',
                    'errors' => $error['errors'] ?? []
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong: ' . $e->getMessage()
            ], 500);
        }
    }
    
    

    public function get_lead_courses($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/leads/courses/{$id}");

            if ($response->successful()) {
                $courses = $response->json('courses'); // Ensure correct key
                return response()->json(['courses' => $courses]);
            } else {
                return response()->json(['status' => 404, 'message' => 'Courses not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
    public function get_enrollment($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/enrollments/{$id}");

            if ($response->successful()) {
                $data = $response->json('data'); // Ensure correct key
                $enrollments = $data['enrollments'];
                
                return response()->json([
                    'enrollments' => $enrollments,
                    'data' => $data,
                    
            ]);
            } else {
                return response()->json(['status' => 404, 'message' => 'Enrollments not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }

    

    public function update_enrollment_form(Request $request, $id)
    {
        $request->validate([
            'email' => 'required|email',
            'password' => 'required',
            'address' => 'required',
            'enrollments' => 'required|array',
            'enrollments.*.course_id' => 'required|integer',
            'enrollments.*.teacher_id' => 'required|integer',
            'enrollments.*.class_timing' => 'required|string',
        ]);

        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/enrollments/{$id}", [
                'lead_id' => $request->lead_id,
                'name' => $request->name,
                'email' => $request->email,
                'cnic' => $request->cnic,
                'password' => $request->password,
                'address' => $request->address,
                'enrollments' => $request->enrollments,
            ]);

            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Enrollment updated successfully.']);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to update enrollment.',
                    'errors' => $error['errors'] ?? []
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'An error occurred: ' . $e->getMessage()], 500);
        }
    }
   
    public function update_enrollment($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/enrollments/{$id}");
            $teachers = $this->fetch_teachers();
            $leads = $this->fetch_leads();
            if ($response->successful()) {
                $data = $response->json()['data'];
                return view('admin.enrollments.update_enrollment', [
                    'enrolls' => $data,
                    'teachers' => $teachers,
                    'leads' => $leads
                ]);
            } else {
                return back()->with('error', 'Failed to fetch Enrolls data.');
            }
        } catch (\Exception $e) {
            return back()->with('error', 'Something went wrong: ' . $e->getMessage());
        }
    }
    public function delete_enrollment($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/enrollments/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Enrollment  deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Unable to delete Enrollment '
            ], $response->status());
        }
    }
}
