<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use Illuminate\Support\Facades\Validator;
use App\DataTables\LabelDataTable;
use Illuminate\Support\Facades\Http;

class LabelController extends Controller
{
    public function label_list(LabelDataTable $dataTable)
    {
        return $dataTable->render('admin.labels.labels_list');
    }

    public function add_label_form(Request $request)
    {
        // Define validation rules
        $validator = Validator::make($request->all(), [
            'label' => 'required|string|max:255',
            'labelcolor' => 'required|string' // Ensure this is required
        ]);
        
        if ($validator->fails()) {
            // Return validation errors
            return response()->json([
                'success' => false,
                'errors' => $validator->errors()
            ], 422);
        }
        
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/labels', [
                'label' => $request->input('label'),
                'labelcolor' => $request->input('labelcolor')
            ]);
            
            if ($response->successful()) {
                return response()->json([
                    'success' => true,
                    'message' => 'Label added successfully'
                ]);
            } else {
                // Extract the error response from the API
                $error = $response->json();
                $message = $error['message'] ?? 'Failed to add label.';
                $errors = $error['errors'] ?? []; // Extract validation errors
                
                // Structure errors for client-side validation
                $formattedErrors = [];
                foreach ($errors as $key => $errorMessages) {
                    if (is_array($errorMessages)) {
                        $formattedErrors[$key] = $errorMessages;
                    } else {
                        $formattedErrors[$key] = [$errorMessages];
                    }
                }
                
                return response()->json([
                    'success' => false,
                    'message' => $message,
                    'errors' => $formattedErrors
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong: ' . $e->getMessage()
            ], 500);
        }
    }
    
    public function delete_label($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/labels/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Label deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Unable to delete Label'
            ], $response->status());
        }
    }
    public function update_label_form(Request $request, $id)
    {
        try {
            $token = session('bearer_token');
    
            // Validate inputs manually (adjust as needed)
            $validator = Validator::make($request->all(), [
                'label' => 'required|string|max:255',
                'labelcolor' => 'required|string' // Ensure this field is required
            ]);
    
            if ($validator->fails()) {
                return response()->json([
                    'success' => false,
                    'message' => 'Validation errors occurred.',
                    'errors' => $validator->errors()->toArray()
                ], 422);
            }
    
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/labels/{$id}", [
                'label' => $request->label,
                'labelcolor' => $request->labelcolor
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Label updated successfully.']);
            } else {
                $error = $response->json();
                $statusCode = $response->status();
    
                if ($statusCode == 422 && isset($error['errors'])) {
                    return response()->json([
                        'success' => false,
                        'message' => $error['message'] ?? 'Failed to update Label.',
                        'errors' => $error['errors']
                    ], $statusCode);
                }
    
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to update Label.'
                ], $statusCode);
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'An error occurred: ' . $e->getMessage()], 500);
        }
    }
    
    
    public function get_label($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/labels/{$id}");

            if ($response->successful()) {
                return response()->json(['label' => $response->json()]);
            } else {
                return response()->json(['label' => 404, 'message' => 'Label not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
}
