<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\DataTables\LeadsDataTable;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Validator;
use Carbon\Carbon; // Import Carbon for date/time manipulation

class LeadsController extends Controller
{
    /**
     * Fetch all statuses from the external API.
     *
     * @return array
     */
    public function fetchStatuses(): array
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/statuses');

        if ($response->successful()) {
            $statuses = $response->json()['data'] ?? [];
            // Extract only the necessary columns
            $statusList = array_map(function ($status) {
                return [
                    'id' => $status['id'],
                    'status' => $status['status'],
                ];
            }, $statuses);

            return $statusList;
        }

        return [];
    }
    public function fetch_courses(): array
    {
        $token = session('bearer_token');

        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/course');

        if ($response->successful()) {
            $courses = $response->json()['courses'] ?? [];
            // Extract only the necessary columns
            $course_list = array_map(function ($courses) {
                return [
                    'id' => $courses['id'],
                    'name' => $courses['name'],
                ];
            }, $courses);

            return $course_list;
        }

        return [];
    }
    public function fetch_labels(): array
    {
        $token = session('bearer_token');

        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/labels');

        if ($response->successful()) {
            $labels = $response->json()['data'] ?? [];
            // Extract only the necessary columns
            $label_list = array_map(function ($label) {
                return [
                    'id' => $label['id'],
                    'label' => $label['label'],
                ];
            }, $labels);

            return $label_list;
        }

        return [];
    }
    public function fetch_teachers(): array
    {
        $token = session('bearer_token');

        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/teachers');

        if ($response->successful()) {
            $teachers = $response->json()['data'] ?? [];
            // Extract only the necessary columns
            $label_list = array_map(function ($teacher) {
                return [
                    'id' => $teacher['id'],
                    'name' => $teacher['name'],
                ];
            }, $teachers);

            return $label_list;
        }

        return [];
    }

    public function leads_list(LeadsDataTable $dataTable)
    {
        $statuses = $this->fetchStatuses();
        $courses = $this->fetch_courses();
        $labels = $this->fetch_labels();
        $teachers = $this->fetch_teachers();
        return $dataTable->render('admin.leads.leads_list', compact('statuses', 'courses', 'labels', 'teachers'));
    }
    public function add_lead_form(Request $request)
{
    // Validate the request data
    $validatedData = $request->validate([
        'name' => 'required|string|max:255',
        'phone' => 'required|numeric|digits_between:10,11', // Correct validation rule
        'lead_manager' => 'required|string|max:255',
        'status_id' => 'required|integer',
        'next_follow_up' => 'required|date_format:Y-m-d H:i:s',
        'courses' => 'required|array',
        'courses.*' => 'integer'
    ]);

    try {
        $token = session('bearer_token');
        $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/leads', [
            'name' => $request->name,
            'phone' => $request->phone,
            'lead_manager' => $request->lead_manager,
            'last_contact' => now()->toDateTimeString(),
            'status_id' => $request->status_id,
            'next_follow_up' => $request->next_follow_up,
            'courses' => $request->courses
        ]);

        if ($response->successful()) {
            $data = $response->json();
            return response()->json([
                'success' => true,
                'message' => 'Lead added successfully.',
                'data' => $data
            ]);
        } else {
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Failed to add lead.',
                'error' => $error['error'] ?? null // Pass additional error details if available
            ], $response->status());
        }
    } catch (\Exception $e) {
        return response()->json([
            'success' => false,
            'message' => 'Something went wrong: ' . $e->getMessage()
        ], 500);
    }
}

    
    
    public function add_leads_label_form(Request $request)
    {
        $request->validate([
            'label_ids' => 'required|array',
            'label_ids.*' => 'integer'
        ]);


        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/leads/label', [
                'lead_id' => $request->lead_id,
                'label_ids' => $request->label_ids,
            ]);

            if ($response->successful()) {
                $data = $response->json();
                return response()->json([
                    'success' => true,
                    'message' => 'Label has been  added to Lead.',
                    'data' => $data
                ]);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add lead.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong: ' . $e->getMessage()
            ], 500);
        }
    }
    public function add_lead_trial_form(Request $request)
    {
        $request->validate([
            'course_id' => 'required',
            'course_id.*' => 'integer',
            'teacher_id' => 'required',
            'teacher_id.*' => 'integer',
            'trial_time' => 'required|date_format:Y-m-d H:i:s',
        ]);

        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/trials/indirect', [
                'lead_id' => $request->lead_id,
                'course_id' => $request->course_id,
                'teacher_id' => $request->teacher_id,
                'trial_time' => $request->trial_time
            ]);

            if ($response->successful()) {
                $data = $response->json();
                return response()->json([
                    'success' => true,
                    'message' => 'Trial has been scheduled.',
                    'data' => $data
                ]);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add lead.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong: ' . $e->getMessage()
            ], 500);
        }
    }



    public function add_feedback_form(Request $request)
    {
        $request->validate([
            'feedback_text' => 'required|string|max:255',
            'follow_up_time' => 'required|date_format:Y-m-d H:i:s',
        ]);

        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/leads/feedbacks', [
                'lead_id' => $request->lead_id,
                'feedback_text' => $request->feedback_text,
                'follow_up_time' => $request->follow_up_time,
            ]);

            if ($response->successful()) {
                $data = $response->json();
                return response()->json([
                    'success' => true,
                    'message' => 'Feedback added successfully.',
                    'data' => $data
                ]);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add lead.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong: ' . $e->getMessage()
            ], 500);
        }
    }
    /**
     * Display the leads list page with DataTable.
     *
     * @param \App\DataTables\LeadsDataTable $dataTable
     * @return \Illuminate\View\View
     */


    public function delete_lead($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/leads/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Lead deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Unable to delete lead'
            ], $response->status());
        }
    }
    public function update_lead_form(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'phone' => 'required|numeric|digits_between:10,11',
            'lead_manager' => 'required|string|max:255',
            'status_id' => 'required|integer',
            'next_follow_up' => 'required|date_format:Y-m-d H:i:s',
            'courses' => 'required|array',
            'courses.*' => 'integer'
        ]);
    
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/leads/{$id}", [
                'name' => $request->name,
                'phone' => $request->phone,
                'lead_manager' => $request->lead_manager,
                'last_contact' => now()->toDateTimeString(),
                'status_id' => $request->status_id,
                'next_follow_up' => $request->next_follow_up,
                'courses' => $request->courses
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Lead updated successfully.']);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to update lead.',
                    'errors' => $error['errors'] ?? [] // Pass additional error details if available
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'An error occurred: ' . $e->getMessage()
            ], 500);
        }
    }
    
    
    



    public function get_lead($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/leads/{$id}");

            if ($response->successful()) {
                return response()->json(['lead' => $response->json()]);
            } else {
                return response()->json(['status' => 404, 'message' => 'Lead not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }


    public function timeline($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/leads/feedbacks/{$id}");

            if ($response->successful()) {
                $data = $response->json()['data'];
                return view('admin.leads.timeline', [
                    'lead' => $data
                ]);
            } else {
                return back()->with('error', 'Failed to fetch lead data.');
            }
        } catch (\Exception $e) {
            return back()->with('error', 'Something went wrong: ' . $e->getMessage());
        }
    }
}
