<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\DataTables\TrialDataTable;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Validator;

class TrialController extends Controller
{
    public function fetch_courses(): array
    {
        $token = session('bearer_token');

        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/course');

        if ($response->successful()) {
            $courses = $response->json()['courses'] ?? [];
            // Extract only the necessary columns
            $course_list = array_map(function ($courses) {
                return [
                    'id' => $courses['id'],
                    'name' => $courses['name'],
                ];
            }, $courses);

            return $course_list;
        }

        return [];
    }
    public function fetch_teachers(): array
    {
        $token = session('bearer_token');

        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/teachers');

        if ($response->successful()) {
            $teachers = $response->json()['data'] ?? [];
            // Extract only the necessary columns
            $teacher_list = array_map(function ($teacher) {
                return [
                    'id' => $teacher['id'],
                    'name' => $teacher['name'],
                ];
            }, $teachers);

            return $teacher_list;
        }

        return [];
    }
    public function fetchStatuses(): array
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/statuses');

        if ($response->successful()) {
            $statuses = $response->json()['data'] ?? [];
            // Extract only the necessary columns
            $statusList = array_map(function ($status) {
                return [
                    'id' => $status['id'],
                    'status' => $status['status'],
                ];
            }, $statuses);

            return $statusList;
        }

        return [];
    }
    public function trials_list(TrialDataTable $dataTable)
    {
        $statuses = $this->fetchStatuses();
        $courses = $this->fetch_courses();
        $teachers = $this->fetch_teachers();
        return $dataTable->render('admin.trials.trials_list' , compact('courses','teachers','statuses'));
    }
    public function delete_trial($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/trials/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Trial deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Unable to delete Trial'
            ], $response->data());
        }
    }
    public function get_trial($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/trials/{$id}");

            if ($response->successful()) {
                return response()->json(['trials' => $response->json()]);
            } else {
                return response()->json(['trials' => 404, 'message' => 'Trial not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
    public function add_trial_form(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'phone' => 'required|numeric|digits_between:10,11',
            'lead_manager' => 'required|string|max:255',
            'status_id' => 'required|integer',
            'next_follow_up' => 'required|date_format:Y-m-d H:i:s',
            'trial_course_id' => 'required|integer',
            'trial_teacher_id' => 'required|integer',
            'trial_time' => 'required|date_format:Y-m-d H:i:s'
        ]);
    
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/trials/direct', [
                'name' => $request->name,
                'phone' => $request->phone,
                'lead_manager' => $request->lead_manager,
                'last_contact' => now()->toDateTimeString(),
                'status_id' => $request->status_id,
                'next_follow_up' => $request->next_follow_up,
                'trial_course_id' => $request->trial_course_id,
                'trial_teacher_id' => $request->trial_teacher_id,
                'trial_time' => $request->trial_time
            ]);
    
            if ($response->successful()) {
                $data = $response->json();
                return response()->json([
                    'success' => true,
                    'message' => 'Trial has been scheduled.',
                    'data' => $data
                ]);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to schedule trial.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong: ' . $e->getMessage()
            ], 500);
        }
    }
    public function update_trial_form(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'course_id' => 'required',
            'teacher_id' => 'required',
            'trial_time' => 'required|date_format:Y-m-d H:i:s',
     
        ]);
    
        if ($validator->fails()) {
            return response()->json(['success' => false, 'errors' => $validator->errors()], 422);
        }
    
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/trials/{$id}", [
                'lead_id' => $request->lead_id,
                'course_id' => $request->course_id,
                'teacher_id' => $request->teacher_id,
                'trial_time' => $request->trial_time
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Trial updated successfully.']);
            } else {
                return response()->json(['success' => false, 'message' => 'Failed to update trial.'], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'An error occurred: ' . $e->getMessage()], 500);
        }
    }
    
    
}    
